function Calculate_MonteCarlo
%
% use Monte-Carlo Simulations to propagate the errors for the bulk density
% and porosity to the estimate of grain density
%

%
% Calculate the Macroporosity
%

packing = 'loose';  % Packing state will be manually overwritten by phi0
dmin=0.02;          % smallest pebble diameter
dmax=140;           % largest boulder diameter
Omega=0.24;         % roundness (angularity) subangular to angular
A=4.1e-20;          % Hamaker constant in J; Olivine
rhop=1420;          % particle (bulk) density in kg/m, jncl. microporosity
grav=0.7*1.3e-4;    % volume-averaged gravity in m/s
q=1.05;             % discretization size ratio X(i+1)/X(i). 
Bocri = 0.1;        % Critical bond number

%
% Generate Vectors for the Monte-Carlo quantities
%

nmc     = 1e6;                             % Number of Monte-Carlo Runs
phi0    = 0.395+0.03*randn(nmc,1);        % Initial packing densities
Psi     = 0.85+0.06*(randn(nmc,1));       % Sphericity  

tic
for i=1:nmc
    phi(i) = MixingZou2011(packing,dmin,dmax,Psi(i),Omega,A,rhop,grav,q,phi0(i),Bocri);
end
toc

save('DataMonteCarlo.mat','phi')

%
% Plot Results
%

figure(1)
clf
histogram(phi*100,50,'Normalization','probability');
set(gca,'fontsize',10)
grid;
xlabel('Macro-Porosity \Phi_M [%]')
ylabel('Fraction of Models')
xlim([5 25])

disp([' '])
disp(['Phi = ' num2str(mean(phi)) '+/-' num2str(std(phi)) ' %.'])
disp([' '])

end