function Plot_Fig4b
%
% use Monte-Carlo Simulations to propagate the errors for the bulk density
% and porosity to the estimate of grain density
%

%
% Generate Vectors for the Monte-Carlo quantities
%

nmc    = 1000000;                           % Number of Monte-Carlo Runs
phi_m1 = 0.28+0.06*rand(nmc,1);             % Microporosity Model Henke 2016
phi_m2 = 0.41+0.14*rand(nmc,1);             % Microporosity Model Flynn 2018
rho_b  = 1190+20*(randn(nmc,1));            % Bulk Density Sugita 2019
phi_M  = 0.1623+0.025944*(randn(nmc,1));    % Macro-Porosity from Monte Carlo

%
% Calculate the distributions
%

for i=1:nmc
    rho_s1(i) = rho_b(i)/((1-phi_m1(i))*(1-phi_M(i)));
    rho_s2(i) = rho_b(i)/((1-phi_m2(i))*(1-phi_M(i)));
end

%
% Plot Results
%

figure(1)
clf
histogram(rho_s1,50,'Normalization','probability');
set(gca,'fontsize',10)
grid;
hold on;
histogram(rho_s2,50,'Normalization','probability');
hold off
xlabel('Grain Density \rho_{Grain} [kg m^{-3}]')
ylabel('Fraction of Models')
xlim([1600 3400])
ylim([0 0.08])
legend([{'Henke et al., 2016'} {'Flynn et al., 2018'}],'location','ne')

%
% Calculate Bulk porosity
%

phi_b1 = 1-mean(rho_b)/mean(rho_s1);
phi_b2 = 1-mean(rho_b)/mean(rho_s2);

disp([' '])
disp(['rho_s(Henke) = ' num2str(mean(rho_s1)) '+/-' num2str(std(rho_s1)) ' kg/m3.'])
disp(['rho_s(Flynn) = ' num2str(mean(rho_s2)) '+/-' num2str(std(rho_s2)) ' kg/m3.'])
disp(['phi_b(Henke) = ' num2str(phi_b1)])
disp(['phi_b(Flynn) = ' num2str(phi_b2)])
disp([' '])

end