function Plot_Fig5

packing = 'loose';     % Packing state will be manually overwritten by phi0
dmin    = 0.02;        % smallest pebble diameter
dmax    = 140;         % largest boulder diameter
Omega   = 0.24;        % roundness (angularity) subangular to angular
A       = 4.1e-20;     % Hamaker constant in J; Olivine. 
rhop    = 1420;        % particle (bulk) density in kg/m, incl. microporosity
grav    = 0.7*1.3e-4;  % volume-averaged gravity in m/s
q       = 1.05;        % discretization size ratio X(i+1)/X(i). 
phi0    = 0.395;       % Porosity
Psi     = 0.833;       % Sphericity

% -------------------------------------------------------------------------
% Macroporosity as a function of Power Law Exponent and Critical Bond
% Number
% -------------------------------------------------------------------------

n=250;
exponent = linspace(2,4,n);
Bocri    = [0.1,1,10];

for j=1:length(Bocri)
    for i=1:n
        phi(i,j) = MixingZou2011_PowerLaw(packing,dmin,dmax,Psi,Omega,A,rhop,grav,q,phi0,exponent(i),Bocri(j));
    end
end

%
% Also calculate for no cohesion
%

grav    = 9.81;
for i=1:n
     phi(i,length(Bocri)+1) = MixingZou2011_PowerLaw(packing,dmin,dmax,Psi,Omega,A,rhop,grav,q,phi0,exponent(i),Bocri(j));
end
grav    = 0.7*1.3e-4;  

% -------------------------------------------------------------------------
% Plot Results
% -------------------------------------------------------------------------

figure(1)
clf
hold on
for j=1:length(Bocri)+1
    h(j) = plot(exponent,phi(:,j)*100);
end
hold off
set(h,'linewidth',1)
set(gca,'fontsize',12)
grid on
box on
xlabel('Power Law Exponent p')
ylabel('Macroporosity \phi_M [%]')
legend(h,[{['B_{cri} = ' num2str(Bocri(1))]} {['B_{cri} = ' num2str(Bocri(2))]} {['B_{cri} = ' num2str(Bocri(3))]} {'no cohesion'}],'location','nw')

% -------------------------------------------------------------------------
% Macroporosity as a function  Dmin
% -------------------------------------------------------------------------

n=250;
p = [2.55,2.65,2.75];
d = logspace(-2,1,n);
Bocri    = 0.1;

for j=1:length(p)
    for i=1:n
        phid(i,j) = MixingZou2011_PowerLaw(packing,d(i),dmax,Psi,Omega,A,rhop,grav,q,phi0,p(j),Bocri);
    end
end

%
% Plot Results
%

figure(2)
clf
hold on
for j=1:length(p)
    g(j) = plot(d,phid(:,j)*100);
end
hold off
set(g,'linewidth',1)
set(gca,'fontsize',12)
set(gca,'xscale','log')
grid on
box on
xlabel('D_{min} [m]')
ylabel('Macroporosity \phi_M [%]')
legend(g,[{['p = ' num2str(p(1))]} {['p = ' num2str(p(2))]} {['p = ' num2str(p(3))]}],'location','nw')

end

